==> nextcloud-23.0.12p1.tgz: nextcloud/apps/photos/l10n/sv.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Publik länk",
    "Photos" : "Bilder",
    "Your memories under your control" : "Dina minnen under din kontroll",
    "All media" : "All media",
    "Videos" : "Videor",
    "Albums" : "Album",
    "Collaborative albums" : "Kollaborativa album",
    "People" : "Personer",
    "Folders" : "Mappar",
    "Favorites" : "Favoriter",
    "On this day" : "På den här dagen",
    "Shared with you" : "Delad med dig",
    "Tags" : "Taggar",
    "Locations" : "Platser",
    "Back" : "Tillbaka",
    "Save." : "Spara.",
    "Create the album." : "Skapa albumet.",
    "Save" : "Spara",
    "Create album" : "Skapa album",
    "Add to Album" : "Lägg till i album",
    "Create a new album." : "Skapa ett nytt album.",
    "Create new album" : "Skapa nytt album",
    "New album" : "Nytt album",
    "Copy the public link" : "Kopiera den offentliga länken",
    "Public link copied!" : "Offentlig länk kopierad!",
    "Copy public link" : "Kopiera offentlig länk",
    "Delete the public link" : "Ta bort den offentliga länken",
    "Share via public link" : "Dela via offentlig länk",
    "Failed to fetch album." : "Misslyckades att hämta album.",
    "Failed to update album." : "Misslyckades att uppdatera album.",
    "An error occurred" : "Ett fel uppstod",
    "_%n photos_::_%n photos_" : ["%n foto","%n foton"],
    "Open the full size \"{name}\" image" : "Öppna bilden \"{name}\" i full storlek",
    "There are no photos or videos yet!" : "Det finns inga bilder eller videor än!",
    "Add to {destination}" : "Lägg till i {destination}",
    "Open the \"{name}\" sub-directory" : "Öppna undermappen \"{name}\"",
    "Back to {folder}" : "Tillbaka till {folder}",
    "Share this folder" : "Dela denna mapp",
    "_{years} year ago_::_{years} years ago_" : ["{years} år sedan","{years} år sedan"],
    "Enable squared photos view" : "Aktivera kvadratiska foto-vyn",
    "View" : "Visa",
    "Download selected photos" : "Ladda ner markerade bilder",
    "Favorite" : "Favorit",
    "Remove from favorites" : "Ta bort från favoriter",
    "Remove person" : "Ta bort person",
    "This folder does not exist" : "Denna mappen finns inte",
    "Loading folders …" : "Laddar mappar...",
    "No photos in here" : "Det finns inga bilder här",
    "Failed to fetch albums list." : "Misslyckades att hämta albumlistan.",
    "Shared albums" : "Delade album",
    "No tags yet" : "Inga taggar än",
    "Photos with tags will show up here" : "Bilder med taggar visas här",
    "Popular tags" : "Populära taggar",
    "Add" : "Lägg till",
    "Create a new album" : "Skapa ett nytt album",
    "Add to album" : "Lägg till i album",
    "Delete selection" : "Ta bort urval",
    "All your media" : "All din media",
    "Tagged photos" : "Taggade bilder",
    "Failed to delete {faceName}." : "Misslyckades att radera {faceName}.",
    "Failed to delete {fileId}." : "Misslyckades att radera {fileId}.",
    "Failed to delete {fileName}." : "Misslyckades att radera {fileName}.",
    "Your photos" : "Dina bilder",
    "Your videos" : "Dina videor",
    "Your folders" : "Dina mappar",
    "Settings" : "Inställningar"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.5.tgz: nextcloud/apps/photos/l10n/sv.js <==
OC.L10N.register(
    "photos",
    {
    "Photos" : "Bilder",
    "Your memories under your control" : "Dina minnen under din kontroll",
    "Videos" : "Videor",
    "People" : "Personer",
    "Folders" : "Mappar",
    "Favorites" : "Favoriter",
    "On this day" : "På den här dagen",
    "Shared with you" : "Delad med dig",
    "Tags" : "Taggar",
    "Locations" : "Platser",
    "Back" : "Tillbaka",
    "Save" : "Spara",
    "Open the full size \"{name}\" image" : "Öppna bilden \"{name}\" i full storlek",
    "Upload from computer" : "Ladda upp från dator",
    "Open the \"{name}\" sub-directory" : "Öppna undermappen \"{name}\"",
    "Back to {folder}" : "Tillbaka till {folder}",
    "Share this folder" : "Dela denna mapp",
    "Enable squared photos view" : "Aktivera kvadratiska foto-vyn",
    "View" : "Visa",
    "An error occurred" : "Ett fel uppstod",
    "Favorite" : "Favorit",
    "Remove from favorites" : "Ta bort från favoriter",
    "This folder does not exist" : "Denna mappen finns inte",
    "No photos in here" : "Det finns inga bilder här",
    "No tags yet" : "Inga taggar än",
    "Photos with tags will show up here" : "Bilder med taggar visas här",
    "Add" : "Lägg till",
    "Download" : "Ladda ner",
    "Delete selection" : "Ta bort urval",
    "Delete" : "Radera",
    "Tagged photos" : "Taggade bilder",
    "Your photos" : "Dina bilder",
    "Your videos" : "Dina videor",
    "Your folders" : "Dina mappar",
    "Settings" : "Inställningar"
},
"nplurals=2; plural=(n != 1);");
